==> patchy-1.5.0.tar.gz: patchy-1.5.0/tests/test_temp_patch.py <==
# -*- encoding:utf-8 -*-
from __future__ import absolute_import, division, print_function, unicode_literals

import sys
from textwrap import dedent

import six

import patchy
import patchy.api


def test_context_manager():
    def sample():
        return 1234

    patch_text = """\
        @@ -1,2 +1,2 @@
         def sample():
        -    return 1234
        +    return 5678
        """

    assert sample() == 1234
    with patchy.temp_patch(sample, patch_text):
        assert sample() == 5678
    assert sample() == 1234


def test_decorator():
    def sample():
        return 3456

    patch_text = """\
        @@ -1,2 +1,2 @@
         def sample():
        -    return 3456
        +    return 7890
        """

    @patchy.temp_patch(sample, patch_text)
    def decorated():
        assert sample() == 7890

    assert sample() == 3456
    decorated()
    assert sample() == 3456


def test_patch_by_path(tmpdir):
    package = tmpdir.mkdir('tmp_by_path_pkg')
    package.join('__init__.py').ensure(file=True)
    package.join('mod.py').write(dedent("""\
        class Foo(object):
            def sample(self):
                return 1
        """))
    sys.path.insert(0, six.text_type(tmpdir))
    patch_text = """\
        @@ -2,2 +2,2 @@
        -    return 1
        +    return 2
        """

    try:
        with patchy.temp_patch('tmp_by_path_pkg.mod.Foo.sample', patch_text):
            from tmp_by_path_pkg.mod import Foo
            assert Foo().sample() == 2
    finally:
        sys.path.pop(0)

    assert Foo().sample() == 1

==> patchy-2.9.0.tar.gz: patchy-2.9.0/tests/test_temp_patch.py <==
from __future__ import annotations

import sys
from textwrap import dedent

import patchy.api


def test_context_manager():
    def sample() -> int:
        return 1234

    patch_text = """\
        @@ -1,2 +1,2 @@
         def sample() -> int:
        -    return 1234
        +    return 5678
        """

    assert sample() == 1234
    with patchy.temp_patch(sample, patch_text):
        assert sample() == 5678
    assert sample() == 1234


def test_decorator():
    def sample() -> int:
        return 3456

    patch_text = """\
        @@ -1,2 +1,2 @@
         def sample() -> int:
        -    return 3456
        +    return 7890
        """

    @patchy.temp_patch(sample, patch_text)
    def decorated() -> None:
        assert sample() == 7890

    assert sample() == 3456
    decorated()
    assert sample() == 3456


def test_patch_by_path(tmp_path):
    package = tmp_path / "tmp_by_path_pkg"
    package.mkdir()
    (package / "__init__.py").write_text("")
    (package / "mod.py").write_text(
        dedent(
            """\
        class Foo(object):
            def sample(self):
                return 1
        """
        )
    )
    patch_text = """\
        @@ -2,1 +2,1 @@
        -    return 1
        +    return 2
        """

    sys.path.insert(0, str(tmp_path))
    try:
        with patchy.temp_patch("tmp_by_path_pkg.mod.Foo.sample", patch_text):
            from tmp_by_path_pkg.mod import Foo

            assert Foo().sample() == 2
    finally:
        sys.path.pop(0)

    assert Foo().sample() == 1
